@@ -10,7 +10,7 @@ use lib qw(../lib);
 	package App;
 
 	use Moose;
-	extends 'Reflex::Object';
+	extends 'Reflex::Base';
 	use Reflex::POE::Event;
 	use PoCoEvent;
 
